Learn R Programming

CARME (version 0.1.1)

W_sel: Adjacency matrix for the South East London set of MSOAs

Description

Adjacency matrix of 152 MSOAs in South East London, used for the data analysis in the paper "Structure induced by a multiple membership transformation on the Conditional Autoregressive model". Column and rows names indicate the MSOA code.

Usage

data(W_sel)

Arguments

Format

A 152x152 symmetric matrix

References

Marco Gramatica. Silvia Liverani. Peter Congdon. "Structure Induced by a Multiple Membership Transformation on the Conditional Autoregressive Model." Bayesian Analysis Advance Publication 1 - 25, 2023. https://doi.org/10.1214/23-BA1370